@@ -64,6 +64,7 @@ Magick::Point Point(const char * str);
 #define myBlueQ blueQuantum
 #define myAlphaQ alphaQuantum
 #define hasMatte() matte()
+#define DistortMethod DistortImageMethod
 #endif
 
 // Option parsers
@@ -74,6 +75,7 @@ Magick::Color Color(const char * str);
 Magick::DisposeType Dispose(const char * str);
 Magick::CompositeOperator Composite(const char * str);
 Magick::ColorspaceType ColorSpace(const char * str);
+Magick::InterlaceType Interlace(const char* str);
 Magick::myFilterType Filter(const char * str);
 Magick::ChannelType Channel(const char * str);
 Magick::GravityType Gravity(const char * str);
